pub async fn exchange_code(
config: &OAuthProviderConfig,
code: &str,
pkce_verifier: &str,
) -> Result<OAuthTokens, AuthError>Expand description
Exchange an authorization code for access and refresh tokens.
pub async fn exchange_code(
config: &OAuthProviderConfig,
code: &str,
pkce_verifier: &str,
) -> Result<OAuthTokens, AuthError>Exchange an authorization code for access and refresh tokens.