Module types

Module types 

Structs

Account
OAuth account record linking a user to an external provider.
NewAccount
Input for creating a new OAuth account.
NewOAuthState
Input for creating a new transient OAuth state.
NewSession
Input for creating a new session.
NewUser
Input for creating a new user.
NewVerification
Input for creating a new verification token.
OAuthState
Transient OAuth state record for CSRF protection and PKCE verification.
PublicAccount
Public account record without sensitive fields like tokens.
PublicUser
Public user record without sensitive fields like password hash.
Session
Session record.
User
User record with all fields including password hash.
Verification
Verification token record.

Enums

OAuthIntent
Whether an OAuth flow is a login or an explicit account link.